@@ -15,58 +15,58 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #ifndef BLUEWIZARD_H
 #define BLUEWIZARD_H
 
 #include <QObject>
 #include <QWizard>
 
-namespace BlueDevil {
-    class Device;
-}
+#include <BluezQt/Manager>
 
 class WizardAgent;
+
 class BlueWizard : public QWizard
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-    BlueWizard(const QUrl& url);
-    virtual ~BlueWizard();
+    explicit BlueWizard();
 
-    QByteArray deviceAddress() const;
-    void setDeviceAddress(const QByteArray& address);
+    BluezQt::DevicePtr device() const;
+    void setDevice(BluezQt::DevicePtr device);
 
-    BlueDevil::Device *device() const;
+    QString pin() const;
+    void setPin(const QString &pin);
 
-    QByteArray pin() const;
-    void setPin(const QByteArray& pin);
+    WizardAgent *agent() const;
+    BluezQt::Manager *manager() const;
 
-    QByteArray preselectedUuid() const;
-    void setPreselectedUuid(const QByteArray &uuid);
-
-    QByteArray preselectedAddress() const;
-    void setPreselectedAddress(const QByteArray &uuid);
-
-    WizardAgent* agent() const;
-
-    enum {Discover, NoPairing, LegacyPairing, LegacyPairingDatabase, KeyboardPairing, SSPPairing, Fail, Connect};
+    enum {
+        Discover,
+        LegacyPairing,
+        LegacyPairingDatabase,
+        KeyboardPairing,
+        SSPPairing,
+        Success,
+        Fail,
+        Connect
+    };
 
 public Q_SLOTS:
     void restartWizard();
-    void setPin(const QString& pin);
-    virtual void done(int result);
+
+private Q_SLOTS:
+    void initJobResult(BluezQt::InitManagerJob *job);
+    void operationalChanged(bool operational);
 
 private:
-    QByteArray m_deviceAddress;
-    BlueDevil::Device * m_device;
-    QByteArray m_pin;
-    QByteArray m_preselectedUuid;
-    QByteArray m_preselectedAddress;
+    void done(int result) Q_DECL_OVERRIDE;
+
+    BluezQt::Manager *m_manager;
     WizardAgent *m_agent;
 
-    bool m_manualPin;
+    BluezQt::DevicePtr m_device;
+    QString m_pin;
 };
 
 #endif // BLUEWIZARD_H
