@@ -24,10 +24,9 @@
 #include <QUrl>
 #include <QIcon>
 #include <QApplication>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
 
 #include <KAboutData>
+#include <KDBusService>
 #include <KLocalizedString>
 
 int main(int argc, char *argv[])
@@ -39,32 +38,25 @@ int main(int argc, char *argv[])
                          KAboutLicense::GPL,
                          i18n("(c) 2010, UFO Coders"));
 
-    aboutData.addAuthor(i18n("Alejandro Fiestas Olivares"), i18n("Maintainer"),
+    aboutData.addAuthor(QStringLiteral("David Rosca"), i18n("Maintainer"),
+                        QStringLiteral("nowrep@gmail.com"), QStringLiteral("http://david.rosca.cz"));
+
+    aboutData.addAuthor(QStringLiteral("Alejandro Fiestas Olivares"), i18n("Previous Maintainer"),
                         QStringLiteral("afiestas@kde.org"), QStringLiteral("http://www.afiestas.org/"));
 
     QApplication app(argc, argv);
-    app.setApplicationName(QStringLiteral("bluedevilwizard"));
-    app.setApplicationVersion(bluedevil_version);
-    app.setApplicationDisplayName(i18n("Bluetooth Wizard"));
-    app.setOrganizationDomain(QStringLiteral("kde.org"));
+    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-system-bluetooth")));
     app.setQuitOnLastWindowClosed(false);
 
-    QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("Bluetooth Wizard"));
-    parser.addVersionOption();
-    parser.addHelpOption();
-    parser.addPositionalArgument(QStringLiteral("URL"), i18n("Device to pair with"), QStringLiteral("[URL]"));
+    KAboutData::setApplicationData(aboutData);
+    KDBusService service(KDBusService::Unique);
 
-    parser.process(app);
+    BlueWizard *wizard = new BlueWizard;
 
-    const QStringList &args = parser.positionalArguments();
-    QUrl url;
-    if (!args.isEmpty()) {
-        url = args.first();
-    }
-
-    new BlueWizard(url);
+    QObject::connect(&service, &KDBusService::activateRequested, wizard, [wizard]() {
+        wizard->setWindowState((wizard->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
+    });
 
     return app.exec();
 }
